@@ -116,7 +116,7 @@ class ChoiceType(TypeDecorator):
         super(ChoiceType, self).__init__(**kw)
 
     def process_bind_param(self, value, dialect):
-        val = [(k, v) for k, v in self.choices.iteritems() if k == value or v == value]
+        val = [(k, v) for k, v in list(self.choices.items()) if k == value or v == value]
         if val:
             return val[0][1]
         return None
@@ -124,7 +124,7 @@ class ChoiceType(TypeDecorator):
     def process_result_value(self, value, dialect):
         if not value:
             return None
-        choices = {v: k for k, v in self.choices.items()}
+        choices = {v: k for k, v in list(self.choices.items())}
         return (value, choices[value])
 
 
